@@ -18,12 +18,14 @@ if args.changelog:
   log = [
     f"[+] - Added Parse-Args (--changelog)",
     f"[+] - Fixed some Errors",
+    f"[+] - Fixed errors when adding multiple categories",
     f"[=] - https://pypi.org/project/simplipy-python/"
   ]
   print(',\n'.join(log))
 
 def _printCommands(commands, Categories, _startMessage):
   global Category
+  OsSystem("cls")
   print(_startMessage)
   print(Color("Commands", "yellow", attrs=["bold"]))
   for x in range(len(commands)):
